#ifndef _SYSTEM_DEF_H_
#define _SYSTEM_DEF_H_

#include <inttypes.h>

#define VER_CODE(major,minor,patch) (major*0x10000+minor*0x100+patch)
/* Software version */
#define SW_VER_ID	"APPFOO"
#define SW_VER_MAJOR	0
#define SW_VER_MINOR	1
#define SW_VER_PATCH	0
#define SW_VER_CODE	VER_CODE(SW_VER_MAJOR,SW_VER_MINOR,SW_VER_PATCH)
/* Hardware version */
#define HW_VER_ID	"MO_CPU1"
#define HW_VER_MAJOR	0
#define HW_VER_MINOR	1
#define HW_VER_PATCH	0
#define HW_VER_CODE	VER_CODE(HW_VER_MAJOR,HW_VER_MINOR,HW_VER_PATCH)
/* Version of mechanical  */
#define MECH_VER_ID     "SOMESTUFF"
#define MECH_VER_MAJOR  0
#define MECH_VER_MINOR  1
#define MECH_VER_PATCH  0
#define MECH_VER_CODE	VER_CODE(MECH_VER_MAJOR,MECH_VER_MINOR,MECH_VER_PATCH)

#define CPU_REF_HZ  4000000	/* reference clock frequency      */
#define CPU_SYS_HZ 21000000	/* default system clock frequency */

#define ISR_SIM_IARB   0xf

#define ISR_QSM_IARB   0xe
#define ISR_QSM_ILSCI  4
#define ISR_QSM_INTV   0x60	/* 2x .. SCI, SPI */

/* PWM and sampling frequency */
#define WITH_SFI_SEL		/* enable selection of sampling frequency */
#define ISR_CTM4_IARB  0xd
#define ISR_CTM4_IL    3
#define ISR_CTM4_INTV  0x80	/* 64x .. 13 used */
#define ISR_CTM4_SFI_INTV (0x80+2)  /* MCSM2 */
#define ISR_CTM4_SFI_IL   5
#define CTM4_SFI_HZ    1000	/* MCSM2 sampling frequency */
#define CTM4_PWM_PDIR0	(volatile uint8_t * const)(0xf87000)
#define CTM4_PWM_PDIR1	(volatile uint8_t * const)(0xf87001)

/* TouCAN subsystem configuration */
#define ISR_CAN_IARB  0xc
#define ISR_CAN_IL    6
#define ISR_CAN_INTV  0xa0	/* 32x .. 19 used */

/* US Digital IRC inputs */
#define USD_IRC_ADDR  ((volatile uint8_t * const)(0xf88000))
#define USD_IRC_GATE  ((volatile uint8_t * const)(0xf88020))
#define USD_IRC_MARK0 ((volatile uint8_t * const)(0xf88028))
#define USD_IRC_MARK1 ((volatile uint8_t * const)(0xf88030))

/* queued ACD module */
#define ISR_QADC_IARB	0xb

/* IIC interface PCD8584 */
#define PCD_8584_PORT0 (volatile uint8_t * const)(0xf10000)
#define PCD_8584_PORT1 (volatile uint8_t * const)(0xf10001)
#define PCD_8584_CSOR  SIM_CSOR4

/* Keyboard KL41 */
#define KL41_LCD_INST  (volatile uint8_t * const)(0xf89000)
#define KL41_LCD_STAT  (volatile uint8_t * const)(0xf89001)
#define KL41_LCD_WDATA (volatile uint8_t * const)(0xf89002)
#define KL41_LCD_RDATA (volatile uint8_t * const)(0xf89003)
#define KL41_LED_WR    (volatile uint8_t * const)(0xf89001)
#define KL41_KBD_WR    (volatile uint8_t * const)(0xf89003)
#define KL41_KBD_RD    (volatile uint8_t * const)(0xf89004)

#if 1
/* SGM Small graphics LCD module 240x64 */
#define SGM_LCD_DATA  (volatile uint8_t * const)(0xf89000)
#define SGM_LCD_CMD   (volatile uint8_t * const)(0xf89001)
#define SGM_LCD_STAT  (volatile uint8_t * const)(0xf89001)
/* Keyboard on MO_KBD1 */
#define SGM_KBDI      (volatile uint8_t * const)(0xf89002)
#define SGM_KBDO      (volatile uint8_t * const)(0xf89002)
#endif

#if 1
/* USB module with PDIUSBD12 */
#define ISR_USB_INTV  0x1a  /* int.vector 26(0x1a) (addr. 0x68)*/
#define PDIUSB_COMMAND_ADDR (volatile uint8_t * const)(0xf8A001)
#define PDIUSB_READ_DATA_ADDR (volatile uint8_t * const)(0xf8A000)
#define PDIUSB_WRITE_DATA_ADDR (volatile uint8_t * const)(0xf8A000)
#define PDIUSB_TEST_IRQ()      (!(*SIM_PORTF0 & 4))
#endif

#endif /* _SYSTEM_DEF_H_ */
